DatabaseHelper class

Constructors

DatabaseHelper()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

userStream → Stream<User?>
no setter

Static Methods

deleteAllCampaigns() → Future<void>
deleteAllUserData() → Future<void>
getCampaignDetails(String campaignId) → Future<String>
getUserDetails() → Future<User?>
initializeDatabase() → Future<void>
insertCampaign(String campaignId, String details) → Future<void>
insertUser(User user) → Future<void>

Constants

campaignTableName → const String
userTableName → const String