NudgeAppComponentViewState class

Constructors

NudgeAppComponentViewState({required double height, required double width, String? errorMessage, bool isViewReady = false, String viewId = ''})

Properties

errorMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
isViewReady → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewId → String
final
width → double
final

Methods

copyWith({double? height, double? width, String? errorMessage, bool? isViewReady, String? viewId}) → NudgeAppComponentViewState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited