NudgeUser class

Constructors

NudgeUser({int slno = 1, required String extId, required String uid, String? name, String? email, String? phone, required Map<String, dynamic> props, String? refBy, String? refNum, int? refLeadNum, String? refByName, String? clientRefCode})
NudgeUser.fromJson(Map<String, dynamic> json)
factory

Properties

clientRefCode → String?
final
email → String?
final
extId → String
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
final
phone → String?
final
props → Map<String, dynamic>
final
refBy → String?
final
refByName → String?
final
refLeadNum → int?
final
refNum → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slno → int
final
uid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

cleanExtId(String extId) → String