User class

Constructors

User({String? uid, String? extId, String? name, String? email, String? phone, Props? props})
User.fromJson(Map<String, dynamic> json)

Properties

email → String?
no setter
extId → String?
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String?
no setter
phone → String?
no setter
props → Props?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid → String?
no setter

Methods

copyWith({String? uid, String? extId, String? name, String? email, String? phone, Props? props}) → User
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited