WidgetDetails class

Constructors

WidgetDetails({required double x, required double y, required double width, required double height, required String label})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
final
label → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final
x → double
final
y → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited