NativeMethodCommand class abstract
- Implementers
- NudgeAddLeadsCommand
- NudgeClearNudges
- NudgeGetUserDetails
- NudgeInitialiseCommand
- NudgePingCommand
- NudgeSendAuthKeyCommand
- NudgeSendKeyOptCommand
- NudgeSendOptCommand
- NudgeSendRefreshTokenCommand
- NudgeSendTargetFailed
- NudgeTrackCommand
- NudgeTrackPageCommand
- NudgeUserIdentifyCommand
- NudgeUserSignOutCommand
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited